@@ -180,7 +180,7 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         self.force_highlight = False
         self.syncpoints = []
         self.in_nested_textview_gutter_expose = False
-        self._cached_match = CachedSequenceMatcher()
+        self._cached_match = CachedSequenceMatcher(self.scheduler)
 
         for buf in self.textbuffer:
             buf.undo_sequence = self.undosequence
@@ -1118,6 +1118,10 @@ class FileDiff(melddoc.MeldDoc, gnomeglade.Component):
         self._connect_buffer_handlers()
         self._set_merge_action_sensitivity()
 
+        # Changing textview sensitivity destroys focus; we reestablish it here
+        if self.cursor.pane is not None:
+            self.textview[self.cursor.pane].grab_focus()
+
         langs = [LanguageManager.get_language_from_file(buf.data.gfile)
                  for buf in self.textbuffer[:self.num_panes]]
 
