@@ -333,8 +333,8 @@ class MeldApp(Gtk.Application):
                     auto_merge=auto_merge, new_tab=options.newtab,
                     focus=i == 0)
             except ValueError as err:
-                log.debug("Couldn't open comparison: %s", error, exc_info=True)
                 error = err
+                log.debug("Couldn't open comparison: %s", error, exc_info=True)
             else:
                 if i > 0:
                     continue
@@ -351,6 +351,9 @@ class MeldApp(Gtk.Application):
                 parser.local_error(error)
             else:
                 print(error)
+            # Delete the error here; otherwise we keep the local app
+            # alive in a reference cycle, and the command line hangs.
+            del error
 
         if parser.should_exit:
             cleanup()
