@@ -1,5 +1,5 @@
 # Copyright (C) 2002-2009 Stephen Kennedy <stevek@gnome.org>
-# Copyright (C) 2012-2013 Kai Willadsen <kai.willadsen@gmail.com>
+# Copyright (C) 2012-2014 Kai Willadsen <kai.willadsen@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,27 +14,28 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gdk
-from gi.repository import Gtk
-import re
+from gi.repository import GtkSource
 
-from meld import misc
-from . import gnomeglade
-
-from meld.conf import _
+from meld.ui import gnomeglade
 
 
 class FindBar(gnomeglade.Component):
     def __init__(self, parent):
         gnomeglade.Component.__init__(self, "findbar.ui", "findbar",
                                       ["arrow_left", "arrow_right"])
-        self.textview = None
-        context = self.find_entry.get_style_context()
-        self.orig_base_color = context.get_background_color(Gtk.StateFlags.NORMAL)
+        self.set_text_view(None)
         self.arrow_left.show()
         self.arrow_right.show()
         parent.connect('set-focus-child', self.on_focus_child)
 
+        settings = GtkSource.SearchSettings()
+        self.match_case.bind_property('active', settings, 'case-sensitive')
+        self.whole_word.bind_property('active', settings, 'at-word-boundaries')
+        self.regex.bind_property('active', settings, 'regex-enabled')
+        self.find_entry.bind_property('text', settings, 'search-text')
+        settings.set_wrap_around(True)
+        self.search_settings = settings
+
     def on_focus_child(self, container, widget):
         if widget is not None:
             visible = self.widget.props.visible
@@ -43,15 +44,25 @@ class FindBar(gnomeglade.Component):
         return False
 
     def hide(self):
-        self.textview = None
+        self.set_text_view(None)
         self.wrap_box.set_visible(False)
         self.widget.hide()
 
-    def start_find(self, textview, text=None):
+    def set_text_view(self, textview):
         self.textview = textview
+        if textview is not None:
+            self.search_context = GtkSource.SearchContext.new(
+                textview.get_buffer(), self.search_settings)
+            self.search_context.set_highlight(True)
+        else:
+            self.search_context = None
+
+    def start_find(self, textview, text=None):
+        self.set_text_view(textview)
         self.replace_label.hide()
         self.replace_entry.hide()
         self.hbuttonbox2.hide()
+        self.find_entry.get_style_context().remove_class("not-found")
         if text:
             self.find_entry.set_text(text)
         self.widget.set_row_spacing(0)
@@ -59,21 +70,22 @@ class FindBar(gnomeglade.Component):
         self.find_entry.grab_focus()
 
     def start_find_next(self, textview):
-        self.textview = textview
+        self.set_text_view(textview)
         if self.find_entry.get_text():
-            self.find_next_button.activate()
+            self.on_find_next_button_clicked(self.find_next_button)
         else:
             self.start_find(self.textview)
 
     def start_find_previous(self, textview, text=None):
-        self.textview = textview
+        self.set_text_view(textview)
         if self.find_entry.get_text():
-            self.find_previous_button.activate()
+            self.on_find_previous_button_clicked(self.find_previous_button)
         else:
             self.start_find(self.textview)
 
     def start_replace(self, textview, text=None):
-        self.textview = textview
+        self.set_text_view(textview)
+        self.find_entry.get_style_context().remove_class("not-found")
         if text:
             self.find_entry.set_text(text)
         self.widget.set_row_spacing(6)
@@ -95,84 +107,49 @@ class FindBar(gnomeglade.Component):
         # Only replace if there is an already-selected match at the cursor
         if (match and oldsel and oldsel[0].equal(newsel[0]) and
                 oldsel[1].equal(newsel[1])):
-            buf.begin_user_action()
-            buf.delete_selection(False, False)
-            buf.insert_at_cursor(self.replace_entry.get_text())
+            self.search_context.replace(
+                newsel[0], newsel[1], self.replace_entry.get_text(), -1)
             self._find_text(0)
-            buf.end_user_action()
 
     def on_replace_all_button_clicked(self, entry):
         buf = self.textview.get_buffer()
         saved_insert = buf.create_mark(
             None, buf.get_iter_at_mark(buf.get_insert()), True)
-        buf.begin_user_action()
-        # Seek to the start
-        buf.place_cursor(buf.get_start_iter())
-        # Can't wrap or end up looping.
-        while self._find_text(start_offset=0, wrap=False):
-            buf.delete_selection(False, False)
-            buf.insert_at_cursor(self.replace_entry.get_text())
-        buf.end_user_action()
+        self.search_context.replace_all(self.replace_entry.get_text(), -1)
         if not saved_insert.get_deleted():
             buf.place_cursor(buf.get_iter_at_mark(saved_insert))
             self.textview.scroll_to_mark(
                 buf.get_insert(), 0.25, True, 0.5, 0.5)
 
     def on_find_entry_changed(self, entry):
-        entry.override_background_color(Gtk.StateType.NORMAL,
-                                        self.orig_base_color)
+        self.find_entry.get_style_context().remove_class("not-found")
+        self._find_text(0)
 
-    def _find_text(self, start_offset=1, backwards=False, wrap=True):
-        match_case = self.match_case.get_active()
-        whole_word = self.whole_word.get_active()
-        regex = self.regex.get_active()
+    def _find_text(self, start_offset=1, backwards=False):
         assert self.textview
+        assert self.search_context
         buf = self.textview.get_buffer()
         insert = buf.get_iter_at_mark(buf.get_insert())
-        tofind_utf8 = self.find_entry.get_text()
-        tofind = tofind_utf8.decode("utf-8")
+
         start, end = buf.get_bounds()
-        text = buf.get_text(start, end, False).decode("utf-8")
-        if not regex:
-            tofind = re.escape(tofind)
-        if whole_word:
-            tofind = r'\b' + tofind + r'\b'
-        try:
-            flags = re.M if match_case else re.M | re.I
-            pattern = re.compile(tofind, flags)
-        except re.error as e:
-            misc.error_dialog(_("Regular expression error"), str(e))
+        self.wrap_box.set_visible(False)
+        if not backwards:
+            insert.forward_chars(start_offset)
+            match, start_iter, end_iter = self.search_context.forward(insert)
+            if match and (start_iter.get_offset() < insert.get_offset()):
+                self.wrap_box.set_visible(True)
         else:
+            match, start_iter, end_iter = self.search_context.backward(insert)
+            if match and (start_iter.get_offset() > insert.get_offset()):
+                self.wrap_box.set_visible(True)
+        if match:
+            buf.place_cursor(start_iter)
+            buf.move_mark(buf.get_selection_bound(), end_iter)
+            self.textview.scroll_to_mark(
+                buf.get_insert(), 0.25, True, 0.5, 0.5)
+            self.find_entry.get_style_context().remove_class("not-found")
+            return True
+        else:
+            buf.place_cursor(buf.get_iter_at_mark(buf.get_insert()))
+            self.find_entry.get_style_context().add_class("not-found")
             self.wrap_box.set_visible(False)
-            if not backwards:
-                match = pattern.search(text,
-                                       insert.get_offset() + start_offset)
-                if match is None and wrap:
-                    self.wrap_box.set_visible(True)
-                    match = pattern.search(text, 0)
-            else:
-                match = None
-                for m in pattern.finditer(text, 0, insert.get_offset()):
-                    match = m
-                if match is None and wrap:
-                    self.wrap_box.set_visible(True)
-                    for m in pattern.finditer(text, insert.get_offset()):
-                        match = m
-            if match:
-                it = buf.get_iter_at_offset(match.start())
-                buf.place_cursor(it)
-                it.forward_chars(match.end() - match.start())
-                buf.move_mark(buf.get_selection_bound(), it)
-                self.textview.scroll_to_mark(
-                    buf.get_insert(), 0.25, True, 0.5, 0.5)
-                return True
-            else:
-                buf.place_cursor(buf.get_iter_at_mark(buf.get_insert()))
-                # FIXME: Even though docs suggest this should work, it does
-                # not. It just sets the selection colour on the text, without
-                # affecting the entry colour at all.
-                color = Gdk.RGBA()
-                color.parse("#ffdddd")
-                self.find_entry.override_background_color(
-                    Gtk.StateType.NORMAL, color)
-                self.wrap_box.set_visible(False)
