@@ -4,6 +4,8 @@ from meld import diffmap
 from meld import linkmap
 from meld import preferences
 from meld import sourceview
+from meld.ui import emblemcellrenderer
 from meld.ui import historyentry
 from meld.ui import msgarea
+from meld.ui import notebook
 from meld.ui import statusbar
