@@ -1,4 +1,6 @@
+# -*- coding: utf-8 -*-
 # Copyright (C) 2002-2005 Stephen Kennedy <stevek@gnome.org>
+# Copyright (C) 2012-2015 Kai Willadsen <kai.willadsen@gmail.com>
 
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -24,22 +26,23 @@
 import shutil
 import tempfile
 
+from meld.conf import _
 from meld.vc import _vc
 
 
 class Vc(_vc.Vc):
 
     CMD = None
-    NAME = ""
+    # Translators: This is the displayed name of a version control system
+    # when no version control system is actually found.
+    NAME = _("None")
     VC_DIR = "."
 
-    def lookup_files(self, dirs, files, directory=None):
-        dirs = [_vc.Dir(d[1], d[0], _vc.STATE_NONE) for d in dirs]
-        files = [_vc.File(f[1], f[0], _vc.STATE_NONE) for f in files]
-        return dirs, files
+    def _update_tree_state_cache(*args):
+        pass
 
     def get_path_for_repo_file(self, path, commit=None):
         with tempfile.NamedTemporaryFile(prefix='meld-tmp', delete=False) as f:
-            with open(path, 'r') as vc_file:
+            with open(path, 'rb') as vc_file:
                 shutil.copyfileobj(vc_file, f)
         return f.name
