@@ -66,6 +66,7 @@ build_exe_options = {
     "includes": ["gi"],
     "packages": ["gi", "weakref"],
     "include_files": include_files,
+    "bin_path_excludes": [""],
 }
 
 
@@ -129,8 +130,8 @@ setup(
     ],
     packages=[
         'meld',
+        'meld.matchers',
         'meld.ui',
-        'meld.util',
         'meld.vc',
     ],
     package_data={
@@ -145,12 +146,15 @@ setup(
          ['COPYING', 'NEWS']
          ),
         ('share/meld',
-         ['data/meld.css', 'data/meld-dark.css']
+         ['data/meld.css']
          ),
         ('share/meld/icons',
          glob.glob("data/icons/*.png") +
          glob.glob("data/icons/COPYING*")
          ),
+        ('share/meld/styles',
+         glob.glob("data/styles/*.xml")
+         ),
         ('share/meld/ui',
          glob.glob("data/ui/*.ui") + glob.glob("data/ui/*.xml")
          ),
